import 'package:cached_network_image/cached_network_image.dart';
import 'package:easy_debounce/easy_debounce.dart';
import 'package:flutter/material.dart';
import 'package:flutter/services.dart';
import 'package:google_fonts/google_fonts.dart';
import 'package:hub/components/templates_components/provisional_schedule_template/provisional_schedule_template_model.dart';
import 'package:hub/shared/utils/dialog_util.dart';
import 'package:hub/shared/utils/limited_text_size.dart';
import 'package:hub/shared/utils/log_util.dart';

import '/backend/api_requests/api_calls.dart';
import '/flutter_flow/flutter_flow_theme.dart';
import '/flutter_flow/flutter_flow_util.dart';
import '/flutter_flow/flutter_flow_widgets.dart';

class ScheduleProvisionalVisitPageWidget extends StatefulWidget {
  const ScheduleProvisionalVisitPageWidget({super.key});

  @override
  State<ScheduleProvisionalVisitPageWidget> createState() => _ScheduleProvisionalVisitPageWidgetState();
}

class _ScheduleProvisionalVisitPageWidgetState extends State<ScheduleProvisionalVisitPageWidget> {
  late ScheduleProvisionalVisitPageModel model;

  @override
  void initState() {
    super.initState();
    model = createModel(context, () => ScheduleProvisionalVisitPageModel());
    model.setState = () => safeSetState(() {});
  }

  @override
  void dispose() {
    model.dispose();

    super.dispose();
  }

  @override
  Widget build(BuildContext context) {
    double limitedBodyFontSize = LimitedFontSizeUtil.getBodyFontSize(context);
    double limitedInputFontSize = LimitedFontSizeUtil.getInputFontSize(context);
    double limitedHeaderFontSize = LimitedFontSizeUtil.getHeaderFontSize(context);
    double limitedSubHeaderFontSize = LimitedFontSizeUtil.getSubHeaderFontSize(context);

    return GestureDetector(
      onTap: () => FocusScope.of(context).unfocus(),
      child: SingleChildScrollView(
        child: Column(
          mainAxisSize: MainAxisSize.max,
          mainAxisAlignment: MainAxisAlignment.start,
          children: [
            Column(
              mainAxisSize: MainAxisSize.max,
              mainAxisAlignment: MainAxisAlignment.spaceBetween,
              children: [
                Form(
                  key: model.formKey,
                  autovalidateMode: AutovalidateMode.onUserInteraction,
                  child: SingleChildScrollView(
                    child: Column(
                      mainAxisSize: MainAxisSize.max,
                      children: [
                        Align(
                          alignment: const AlignmentDirectional(-1.0, 0.0),
                          child: Padding(
                            padding: const EdgeInsetsDirectional.fromSTEB(24.0, 24.0, 0.0, 24.0),
                            child: Text(
                              FFLocalizations.of(context).getText('uj8acuab'),
                              textAlign: TextAlign.start,
                              overflow: TextOverflow.clip,
                              style: FlutterFlowTheme.of(context).bodyMedium.override(
                                    fontFamily: FlutterFlowTheme.of(context).bodyMediumFamily,
                                    fontSize: limitedHeaderFontSize,
                                    letterSpacing: 0.0,
                                    fontWeight: FontWeight.bold,
                                    useGoogleFonts:
                                        GoogleFonts.asMap().containsKey(FlutterFlowTheme.of(context).bodyMediumFamily),
                                  ),
                            ),
                          ),
                        ),
                        Container(
                          width: double.infinity,
                          decoration: BoxDecoration(
                            color: FlutterFlowTheme.of(context).primaryBackground,
                          ),
                          child: Column(
                            mainAxisSize: MainAxisSize.max,
                            crossAxisAlignment: CrossAxisAlignment.center,
                            children: [
                              Align(
                                alignment: const AlignmentDirectional(-1.0, 0.0),
                                child: Padding(
                                  padding: const EdgeInsetsDirectional.fromSTEB(24.0, 0.0, 0.0, 0.0),
                                  child: Text(
                                    FFLocalizations.of(context).getText(
                                      '8d3679lf' /* Propriedade */,
                                    ),
                                    style: FlutterFlowTheme.of(context).bodyMedium.override(
                                          fontFamily: FlutterFlowTheme.of(context).bodyMediumFamily,
                                          letterSpacing: 0.0,
                                          useGoogleFonts: GoogleFonts.asMap()
                                              .containsKey(FlutterFlowTheme.of(context).bodyMediumFamily),
                                          fontSize: limitedSubHeaderFontSize,
                                        ),
                                  ),
                                ),
                              ),
                              Padding(
                                padding: const EdgeInsetsDirectional.fromSTEB(24.0, 10.0, 24.0, 10.0),
                                child: Container(
                                  width: double.infinity,
                                  height: 50.0,
                                  decoration: BoxDecoration(
                                    borderRadius: const BorderRadius.only(
                                      bottomLeft: Radius.circular(50.0),
                                      bottomRight: Radius.circular(50.0),
                                      topLeft: Radius.circular(50.0),
                                      topRight: Radius.circular(50.0),
                                    ),
                                    border: Border.all(
                                      color: FlutterFlowTheme.of(context).customColor5,
                                    ),
                                  ),
                                  child: Padding(
                                    padding: const EdgeInsets.all(5.0),
                                    child: Row(
                                      mainAxisSize: MainAxisSize.max,
                                      mainAxisAlignment: MainAxisAlignment.start,
                                      children: [
                                        ClipRRect(
                                          borderRadius: const BorderRadius.only(
                                            bottomLeft: Radius.circular(50.0),
                                            bottomRight: Radius.circular(50.0),
                                            topLeft: Radius.circular(50.0),
                                            topRight: Radius.circular(50.0),
                                          ),
                                          child: CachedNetworkImage(
                                            fadeInDuration: const Duration(milliseconds: 200),
                                            fadeOutDuration: const Duration(milliseconds: 200),
                                            imageUrl:
                                                'https://freaccess.com.br/freaccess/Images/Clients/${model.cliUUID}.png',
                                            width: 35.0,
                                            height: 35.0,
                                            fit: BoxFit.contain,
                                            memCacheWidth: 35,
                                            memCacheHeight: 35,
                                          ),
                                        ),
                                        Expanded(
                                          child: Padding(
                                            padding: const EdgeInsetsDirectional.fromSTEB(15.0, 0.0, 0.0, 0.0),
                                            child: Text(
                                              model.ownerName,
                                              overflow: TextOverflow.ellipsis,
                                              maxLines: 1,
                                              style: FlutterFlowTheme.of(context).bodyMedium.override(
                                                    fontFamily: FlutterFlowTheme.of(context).bodyMediumFamily,
                                                    letterSpacing: 0.0,
                                                    useGoogleFonts: GoogleFonts.asMap()
                                                        .containsKey(FlutterFlowTheme.of(context).bodyMediumFamily),
                                                    fontSize: limitedBodyFontSize,
                                                  ),
                                            ),
                                          ),
                                        ),
                                      ],
                                    ),
                                  ),
                                ),
                              ),
                            ],
                          ),
                        ),
                        Container(
                          decoration: const BoxDecoration(),
                          child: SingleChildScrollView(
                            child: Column(
                              mainAxisSize: MainAxisSize.max,
                              mainAxisAlignment: MainAxisAlignment.spaceEvenly,
                              children: [
                                Align(
                                  alignment: const AlignmentDirectional(-1.0, 0.0),
                                  child: Padding(
                                    padding: const EdgeInsetsDirectional.fromSTEB(24.0, 10.0, 0.0, 10.0),
                                    child: Text(
                                      FFLocalizations.of(context).getText(
                                        'z6aawgqa' /* Dados da Visita */,
                                      ),
                                      style: FlutterFlowTheme.of(context).bodyMedium.override(
                                            fontFamily: FlutterFlowTheme.of(context).bodyMediumFamily,
                                            letterSpacing: 0.0,
                                            useGoogleFonts: GoogleFonts.asMap()
                                                .containsKey(FlutterFlowTheme.of(context).bodyMediumFamily),
                                            fontSize: limitedSubHeaderFontSize,
                                          ),
                                    ),
                                  ),
                                ),
                                Column(
                                  mainAxisSize: MainAxisSize.max,
                                  children: [
                                    Container(
                                      height: 80.0,
                                      decoration: const BoxDecoration(),
                                      alignment: const AlignmentDirectional(0.0, 0.0),
                                      child: Padding(
                                        padding: const EdgeInsetsDirectional.fromSTEB(24.0, 0.0, 24.0, 0.0),
                                        child: SizedBox(
                                          width: double.infinity,
                                          child: TextFormField(
                                            controller: model.personNameTextController,
                                            focusNode: model.personNameFocusNode,
                                            cursorColor: FlutterFlowTheme.of(context).primary,
                                            onChanged: (_) => EasyDebounce.debounce(
                                              'model.personNameTextController',
                                              const Duration(milliseconds: 500),
                                              () => setState(() {}),
                                            ),
                                            autofocus: false,
                                            textInputAction: TextInputAction.next,
                                            obscureText: false,
                                            decoration: InputDecoration(
                                              isDense: true,
                                              labelText: FFLocalizations.of(context).getText(
                                                'wehvxbz4' /* Nome / Apelido do Visitante */,
                                              ),
                                              labelStyle: FlutterFlowTheme.of(context).bodyMedium.override(
                                                    fontFamily: FlutterFlowTheme.of(context).bodyMediumFamily,
                                                    color: FlutterFlowTheme.of(context).primaryText,
                                                    letterSpacing: 0.0,
                                                    useGoogleFonts: GoogleFonts.asMap()
                                                        .containsKey(FlutterFlowTheme.of(context).bodyMediumFamily),
                                                    fontSize: limitedInputFontSize,
                                                  ),
                                              hintStyle: FlutterFlowTheme.of(context).labelMedium.override(
                                                    fontFamily: FlutterFlowTheme.of(context).labelMediumFamily,
                                                    color: FlutterFlowTheme.of(context).primaryText,
                                                    letterSpacing: 0.0,
                                                    useGoogleFonts: GoogleFonts.asMap()
                                                        .containsKey(FlutterFlowTheme.of(context).labelMediumFamily),
                                                    fontSize: limitedInputFontSize,
                                                  ),
                                              enabledBorder: OutlineInputBorder(
                                                borderSide: BorderSide(
                                                  color: FlutterFlowTheme.of(context).customColor5,
                                                  width: 0.5,
                                                ),
                                                borderRadius: BorderRadius.circular(10.0),
                                              ),
                                              focusedBorder: OutlineInputBorder(
                                                borderSide: BorderSide(
                                                  color: FlutterFlowTheme.of(context).primary,
                                                  width: 0.5,
                                                ),
                                                borderRadius: BorderRadius.circular(10.0),
                                              ),
                                              errorBorder: OutlineInputBorder(
                                                borderSide: BorderSide(
                                                  color: FlutterFlowTheme.of(context).error,
                                                  width: 0.5,
                                                ),
                                                borderRadius: BorderRadius.circular(10.0),
                                              ),
                                              focusedErrorBorder: OutlineInputBorder(
                                                borderSide: BorderSide(
                                                  color: FlutterFlowTheme.of(context).error,
                                                  width: 0.5,
                                                ),
                                                borderRadius: BorderRadius.circular(10.0),
                                              ),
                                              suffixIcon: Icon(
                                                Icons.person,
                                                color: FlutterFlowTheme.of(context).accent1,
                                              ),
                                            ),
                                            style: FlutterFlowTheme.of(context).bodyMedium.override(
                                                  fontFamily: FlutterFlowTheme.of(context).bodyMediumFamily,
                                                  color: FlutterFlowTheme.of(context).primaryText,
                                                  letterSpacing: 0.0,
                                                  useGoogleFonts: GoogleFonts.asMap()
                                                      .containsKey(FlutterFlowTheme.of(context).bodyMediumFamily),
                                                  fontSize: limitedInputFontSize,
                                                ),
                                            textAlign: TextAlign.start,
                                            maxLines: null,
                                            validator: model.personNameTextControllerValidator.asValidator(context),
                                          ),
                                        ),
                                      ),
                                    ),
                                  ],
                                ),
                                Column(
                                  mainAxisSize: MainAxisSize.min,
                                  mainAxisAlignment: MainAxisAlignment.start,
                                  children: [
                                    SizedBox(
                                      height: 80.0,
                                      child: Stack(
                                        alignment: const AlignmentDirectional(0.0, 0.0),
                                        children: [
                                          Padding(
                                            padding: const EdgeInsetsDirectional.fromSTEB(24.0, 0.0, 24.0, 0.0),
                                            child: TextFormField(
                                              controller: model.dateTimeTextController,
                                              focusNode: model.dateTimeFocusNode,
                                              cursorColor: FlutterFlowTheme.of(context).primary,
                                              onChanged: (_) => EasyDebounce.debounce(
                                                'model.dateTimeTextController',
                                                const Duration(milliseconds: 500),
                                                () => setState(() {}),
                                              ),
                                              readOnly: true,
                                              autofocus: false,
                                              obscureText: false,
                                              decoration: InputDecoration(
                                                isDense: true,
                                                labelText: FFLocalizations.of(context).getVariableText(
                                                  ptText: "Data de Validade da Visita",
                                                  enText: "Visit Validity Date",
                                                ),
                                                labelStyle: FlutterFlowTheme.of(context).bodyMedium.override(
                                                      fontFamily: FlutterFlowTheme.of(context).bodyMediumFamily,
                                                      letterSpacing: 0.0,
                                                      useGoogleFonts: GoogleFonts.asMap()
                                                          .containsKey(FlutterFlowTheme.of(context).bodyMediumFamily),
                                                      fontSize: limitedInputFontSize,
                                                    ),
                                                enabledBorder: OutlineInputBorder(
                                                  borderSide: BorderSide(
                                                    color: FlutterFlowTheme.of(context).customColor5,
                                                    width: 0.5,
                                                  ),
                                                  borderRadius: BorderRadius.circular(8.0),
                                                ),
                                                focusedBorder: OutlineInputBorder(
                                                  borderSide: BorderSide(
                                                    color: FlutterFlowTheme.of(context).primary,
                                                    width: 0.5,
                                                  ),
                                                  borderRadius: BorderRadius.circular(8.0),
                                                ),
                                                errorBorder: OutlineInputBorder(
                                                  borderSide: BorderSide(
                                                    color: FlutterFlowTheme.of(context).error,
                                                    width: 0.5,
                                                  ),
                                                  borderRadius: BorderRadius.circular(8.0),
                                                ),
                                                focusedErrorBorder: OutlineInputBorder(
                                                  borderSide: BorderSide(
                                                    color: FlutterFlowTheme.of(context).error,
                                                    width: 0.5,
                                                  ),
                                                  borderRadius: BorderRadius.circular(8.0),
                                                ),
                                                suffixIcon: Icon(
                                                  Icons.date_range,
                                                  color: FlutterFlowTheme.of(context).accent1,
                                                ),
                                              ),
                                              style: FlutterFlowTheme.of(context).bodyMedium.override(
                                                    fontFamily: FlutterFlowTheme.of(context).bodyMediumFamily,
                                                    letterSpacing: 0.0,
                                                    useGoogleFonts: GoogleFonts.asMap()
                                                        .containsKey(FlutterFlowTheme.of(context).bodyMediumFamily),
                                                    fontSize: limitedInputFontSize,
                                                  ),
                                              textAlign: TextAlign.start,
                                              validator: model.dateTimeTextControllerValidator.asValidator(context),
                                            ),
                                          ),
                                          Padding(
                                            padding: const EdgeInsetsDirectional.fromSTEB(24.0, 0.0, 24.0, 0.0),
                                            child: InkWell(
                                              splashColor: Colors.transparent,
                                              focusColor: Colors.transparent,
                                              hoverColor: Colors.transparent,
                                              highlightColor: Colors.transparent,
                                              onTap: () async {
                                                final datePickedDate = await showDatePicker(
                                                  context: context,
                                                  initialDate: getCurrentTimestamp,
                                                  firstDate: (getCurrentTimestamp),
                                                  lastDate: DateTime(2050),
                                                  builder: (context, child) {
                                                    return wrapInMaterialDatePickerTheme(
                                                      context,
                                                      child!,
                                                      headerBackgroundColor: FlutterFlowTheme.of(context).primary,
                                                      headerForegroundColor: FlutterFlowTheme.of(context).info,
                                                      headerTextStyle:
                                                          FlutterFlowTheme.of(context).headlineLarge.override(
                                                                fontFamily:
                                                                    FlutterFlowTheme.of(context).headlineLargeFamily,
                                                                fontSize: 32.0,
                                                                letterSpacing: 0.0,
                                                                fontWeight: FontWeight.w600,
                                                                useGoogleFonts: GoogleFonts.asMap().containsKey(
                                                                    FlutterFlowTheme.of(context).headlineLargeFamily),
                                                              ),
                                                      pickerBackgroundColor:
                                                          FlutterFlowTheme.of(context).secondaryBackground,
                                                      pickerForegroundColor: FlutterFlowTheme.of(context).primaryText,
                                                      selectedDateTimeBackgroundColor:
                                                          FlutterFlowTheme.of(context).primary,
                                                      selectedDateTimeForegroundColor:
                                                          FlutterFlowTheme.of(context).info,
                                                      actionButtonForegroundColor:
                                                          FlutterFlowTheme.of(context).primaryText,
                                                      iconSize: 24.0,
                                                    );
                                                  },
                                                );

                                                TimeOfDay? datePickedTime;
                                                if (datePickedDate != null) {
                                                  datePickedTime = await showTimePicker(
                                                    context: context,
                                                    initialTime: TimeOfDay.fromDateTime(getCurrentTimestamp),
                                                    builder: (context, child) {
                                                      return wrapInMaterialTimePickerTheme(
                                                        context,
                                                        child!,
                                                        headerBackgroundColor: FlutterFlowTheme.of(context).primary,
                                                        headerForegroundColor: FlutterFlowTheme.of(context).info,
                                                        headerTextStyle:
                                                            FlutterFlowTheme.of(context).headlineLarge.override(
                                                                  fontFamily:
                                                                      FlutterFlowTheme.of(context).headlineLargeFamily,
                                                                  fontSize: 32.0,
                                                                  letterSpacing: 0.0,
                                                                  fontWeight: FontWeight.w600,
                                                                  useGoogleFonts: GoogleFonts.asMap().containsKey(
                                                                      FlutterFlowTheme.of(context).headlineLargeFamily),
                                                                ),
                                                        pickerBackgroundColor:
                                                            FlutterFlowTheme.of(context).secondaryBackground,
                                                        pickerForegroundColor: FlutterFlowTheme.of(context).info,
                                                        selectedDateTimeBackgroundColor:
                                                            FlutterFlowTheme.of(context).primary,
                                                        pickerDialForegroundColor:
                                                            FlutterFlowTheme.of(context).primaryText,
                                                        selectedDateTimeForegroundColor:
                                                            FlutterFlowTheme.of(context).info,
                                                        actionButtonForegroundColor:
                                                            FlutterFlowTheme.of(context).primaryText,
                                                        iconSize: 24.0,
                                                      );
                                                    },
                                                  );
                                                }

                                                if (datePickedDate != null && datePickedTime != null) {
                                                  safeSetState(() {
                                                    model.datePicked = DateTime(
                                                      datePickedDate.year,
                                                      datePickedDate.month,
                                                      datePickedDate.day,
                                                      datePickedTime!.hour,
                                                      datePickedTime.minute,
                                                    );
                                                  });
                                                }
                                                setState(() {
                                                  model.datePicked = model.datePicked;
                                                  model.dateTimeTextController?.text = dateTimeFormat(
                                                    "dd/MM/yyyy HH:mm:ss",
                                                    model.datePicked,
                                                    locale: FFLocalizations.of(context).languageCode,
                                                  );

                                                  model.dateTimeTextController?.selection = TextSelection.collapsed(
                                                      offset: model.dateTimeTextController!.text.length);
                                                });
                                              },
                                              child: Container(
                                                width: double.infinity,
                                                height: 50.0,
                                                decoration: BoxDecoration(
                                                  borderRadius: BorderRadius.circular(8.0),
                                                ),
                                                alignment: const AlignmentDirectional(0.0, 0.0),
                                              ),
                                            ),
                                          ),
                                        ],
                                      ),
                                    ),
                                  ],
                                ),
                                Padding(
                                  padding: const EdgeInsetsDirectional.fromSTEB(0.0, 10.0, 0.0, 10.0),
                                  child: Column(
                                    mainAxisSize: MainAxisSize.max,
                                    children: [
                                      Align(
                                        alignment: const AlignmentDirectional(0.0, 0.0),
                                        child: Container(
                                          decoration: const BoxDecoration(),
                                          alignment: const AlignmentDirectional(0.0, 0.0),
                                          child: Align(
                                            alignment: const AlignmentDirectional(0.0, 0.0),
                                            child: Padding(
                                              padding: const EdgeInsetsDirectional.fromSTEB(24.0, 0.0, 24.0, 0.0),
                                              child: SizedBox(
                                                width: double.infinity,
                                                child: TextFormField(
                                                  controller: model.notesTextController,
                                                  focusNode: model.notesFocusNode,
                                                  autofocus: false,
                                                  showCursor: true,
                                                  cursorColor: FlutterFlowTheme.of(context).primary,
                                                  textInputAction: TextInputAction.next,
                                                  obscureText: false,
                                                  decoration: InputDecoration(
                                                    isDense: true,
                                                    counterStyle: FlutterFlowTheme.of(context).bodyText1.override(
                                                          fontFamily: FlutterFlowTheme.of(context).bodyText1Family,
                                                          color: FlutterFlowTheme.of(context).primaryText,
                                                          fontSize: limitedInputFontSize,
                                                        ),
                                                    labelText: FFLocalizations.of(context).getText(
                                                      'cw8b3tbb' /* Observação da Visita */,
                                                    ),
                                                    labelStyle: FlutterFlowTheme.of(context).bodyMedium.override(
                                                          fontFamily: FlutterFlowTheme.of(context).bodyMediumFamily,
                                                          color: FlutterFlowTheme.of(context).primaryText,
                                                          letterSpacing: 0.0,
                                                          useGoogleFonts: GoogleFonts.asMap().containsKey(
                                                              FlutterFlowTheme.of(context).bodyMediumFamily),
                                                          fontSize: limitedInputFontSize,
                                                        ),
                                                    hintStyle: FlutterFlowTheme.of(context).labelMedium.override(
                                                          fontFamily: FlutterFlowTheme.of(context).labelMediumFamily,
                                                          color: FlutterFlowTheme.of(context).primaryText,
                                                          letterSpacing: 0.0,
                                                          useGoogleFonts: GoogleFonts.asMap().containsKey(
                                                              FlutterFlowTheme.of(context).labelMediumFamily),
                                                          fontSize: limitedInputFontSize,
                                                        ),
                                                    enabledBorder: OutlineInputBorder(
                                                      borderSide: BorderSide(
                                                        color: FlutterFlowTheme.of(context).customColor5,
                                                        width: 0.5,
                                                      ),
                                                      borderRadius: BorderRadius.circular(10.0),
                                                    ),
                                                    focusedBorder: OutlineInputBorder(
                                                      borderSide: BorderSide(
                                                        color: FlutterFlowTheme.of(context).primary,
                                                        width: 0.5,
                                                      ),
                                                      borderRadius: BorderRadius.circular(10.0),
                                                    ),
                                                    errorBorder: OutlineInputBorder(
                                                      borderSide: BorderSide(
                                                        color: FlutterFlowTheme.of(context).error,
                                                        width: 0.5,
                                                      ),
                                                      borderRadius: BorderRadius.circular(10.0),
                                                    ),
                                                    focusedErrorBorder: OutlineInputBorder(
                                                      borderSide: BorderSide(
                                                        color: FlutterFlowTheme.of(context).error,
                                                        width: 0.5,
                                                      ),
                                                      borderRadius: BorderRadius.circular(10.0),
                                                    ),
                                                    suffixIcon: Icon(
                                                      Icons.text_fields,
                                                      color: FlutterFlowTheme.of(context).accent1,
                                                    ),
                                                  ),
                                                  style: FlutterFlowTheme.of(context).bodyMedium.override(
                                                        fontFamily: FlutterFlowTheme.of(context).bodyMediumFamily,
                                                        color: FlutterFlowTheme.of(context).primaryText,
                                                        letterSpacing: 0.0,
                                                        useGoogleFonts: GoogleFonts.asMap()
                                                            .containsKey(FlutterFlowTheme.of(context).bodyMediumFamily),
                                                        fontSize: limitedInputFontSize,
                                                      ),
                                                  textAlign: TextAlign.start,
                                                  maxLines: 3,
                                                  maxLength: 100,
                                                  maxLengthEnforcement: MaxLengthEnforcement.enforced,
                                                  validator: model.notesTextControllerValidator.asValidator(context),
                                                ),
                                              ),
                                            ),
                                          ),
                                        ),
                                      ),
                                    ],
                                  ),
                                ),
                              ],
                            ),
                          ),
                        ),
                        FFButtonWidget(
                          onPressed: !model.isFormValid()
                              ? null
                              : () async {
                                  try {
                                    model.provVisitSchedule = await PhpGroup.postProvVisitSchedulingCall.call(
                                      data: DateFormat('dd/MM/yyyy HH:mm:ss').format(DateFormat('dd/MM/yyyy HH:mm:ss')
                                          .parse(model.dateTimeTextController.text)
                                          .add(const Duration(hours: 3))),
                                      motivo: model.notesTextController.text,
                                      nome: model.personNameTextController.text,
                                      proID: model.ownerUUID,
                                    );
                                    if (PhpGroup.postProvVisitSchedulingCall
                                            .error((model.provVisitSchedule?.jsonBody ?? '')) ==
                                        false) {
                                      await DialogUtil.success(
                                          context,
                                          FFLocalizations.of(context).getVariableText(
                                              ptText: "Agendamento Provisório Realizado com Sucesso!",
                                              enText: "Provisional Scheduling Successfully Completed"));
                                      safeSetState(() {
                                        model.dateTimeTextController?.clear();
                                        model.personNameTextController?.clear();
                                        model.notesTextController?.clear();
                                      });
                                    } else {
                                      var message = PhpGroup.postProvVisitSchedulingCall
                                          .msg((model.provVisitSchedule?.jsonBody ?? ''));
                                      if (message != null) {
                                        await DialogUtil.error(context, message);
                                      } else {
                                        await DialogUtil.errorDefault(context);
                                      }
                                    }
                                    setState(() {});
                                  } catch (e, s) {
                                    await DialogUtil.errorDefault(context);
                                    LogUtil.requestAPIFailed(
                                        "processRequest.php", "", "Cadastrar Visita Provisória", e, s);
                                  }
                                },
                          showLoadingIndicator: true,
                          text: FFLocalizations.of(context).getText('bv5fg9sv' /* Enviar */),
                          options: FFButtonOptions(
                            height: 30.0 * MediaQuery.textScalerOf(context).scale(1),
                            padding: const EdgeInsetsDirectional.fromSTEB(24.0, 0.0, 24.0, 0.0),
                            iconPadding: const EdgeInsetsDirectional.fromSTEB(0.0, 0.0, 0.0, 0.0),
                            color: FlutterFlowTheme.of(context).primary,
                            textStyle: FlutterFlowTheme.of(context).titleSmall.override(
                                  fontFamily: FlutterFlowTheme.of(context).titleSmallFamily,
                                  color: Colors.white,
                                  letterSpacing: 0.0,
                                  useGoogleFonts:
                                      GoogleFonts.asMap().containsKey(FlutterFlowTheme.of(context).titleSmallFamily),
                                  fontSize: limitedInputFontSize,
                                ),
                            elevation: 3.0,
                            borderSide: const BorderSide(color: Colors.transparent, width: 1.0),
                            borderRadius: BorderRadius.circular(8.0),
                            disabledColor: FlutterFlowTheme.of(context).customColor5,
                            disabledTextColor: Colors.white,
                          ),
                        ),
                      ],
                    ),
                  ),
                ),
              ],
            ),
          ].addToStart(const SizedBox(height: 4.0)).addToEnd(const SizedBox(height: 40.0)),
        ),
      ),
    );
  }
}
