import 'package:flutter/material.dart';
import 'package:hub/backend/api_requests/api_manager.dart';
import 'package:hub/features/history/index.dart';
import 'package:hub/flutter_flow/flutter_flow_model.dart';
import 'package:hub/flutter_flow/request_manager.dart';
import 'package:hub/shared/helpers/storage/base_storage.dart';
import 'package:hub/shared/helpers/storage/storage_helper.dart';

class AcessHistoryPageModel extends FlutterFlowModel<AccessHistoryScreen> {
  late final String devUUID;
  late final String userUUID;
  late final String cliUUID;

  final unfocusNode = FocusNode();
  final _accessHistoryManager = FutureRequestManager<ApiCallResponse>();
  Future<ApiCallResponse> accessHistory({
    String? uniqueQueryKey,
    bool? overrideCache,
    required Future<ApiCallResponse> Function() requestFn,
  }) =>
      _accessHistoryManager.performRequest(
        uniqueQueryKey: uniqueQueryKey,
        overrideCache: overrideCache,
        requestFn: requestFn,
      );
  void clearAccessHistoryCache() => _accessHistoryManager.clear();
  void clearAccessHistoryCacheKey(String? uniqueKey) => _accessHistoryManager.clearRequest(uniqueKey);

  @override
  void initState(BuildContext context) {
    initDatabase();
  }

  Future<void> initDatabase() async {
    devUUID = (await StorageHelper().get(KeychainStorageKey.devUUID.value)) ?? '';
    userUUID = (await StorageHelper().get(KeychainStorageKey.userUUID.value)) ?? '';
    cliUUID = (await StorageHelper().get(KeychainStorageKey.clientUUID.value)) ?? '';
  }

  @override
  void dispose() {
    unfocusNode.dispose();

    clearAccessHistoryCache();
  }
}
